@@ -15,7 +15,7 @@ use Locale::Language;
 use Readonly;
 Readonly our $DPI_OPTION_POS => 3;
 
-our $VERSION = '2.11.0';
+our $VERSION = '2.12.7';
 my $EMPTY = q{};
 my $COMMA = q{,};
 
@@ -25,7 +25,15 @@ my ( %languages, %installable_languages, $installed, $setup, $version,
 # Taken from
 # https://github.com/tesseract-ocr/tesseract/blob/master/doc/tesseract.1.asc#languages
 my @installable_languages =
-  qw(afr amh ara asm aze aze-cyrl bel ben bod bos bre bul cat ceb ces chi-sim chi-sim-vert chi-tra chi-tra-vert chr cos cym dan dan-frak deu deu-frak div dzo ell eng enm epo equ est eus fao fas fil fin fra frk frm fry gla gle gle-uncial glg grc guj hat heb hin hrv hun hye iku ind isl ita ita-old jav jpn jpn-vert kan kat kat-old kaz khm kir kmr kor kor-vert lao lat lav lit ltz mal mar mkd mlt mon mri msa mya nep nld nor oci ori pan pol por pus que ron rus san sin slk slk-frak slv snd spa spa_old sqi srp srp_latn sun swa swe swe-frak syr tam tat tel tgk tgl tha tir ton tur uig ukr urd uzb uzb_cyrl vie yid yor);
+  qw(afr amh ara asm aze aze-cyrl bel ben bod bos bre bul cat ceb ces chi-sim
+  chi-sim-vert chi-tra chi-tra-vert chr cos cym dan dan-frak deu deu-frak div
+  dzo ell eng enm epo equ est eus fao fas fil fin fra frk frm fry gla gle
+  gle-uncial glg grc guj hat heb hin hrv hun hye iku ind isl ita ita-old jav
+  jpn jpn-vert kan kat kat-old kaz khm kir kmr kor kor-vert lao lat lav lit
+  ltz mal mar mkd mlt mon mri msa mya nep nld nor oci ori pan pol por pus que
+  ron rus san sin slk slk-frak slv snd spa spa_old sqi srp srp_latn sun swa
+  swe swe-frak syr tam tat tel tgk tgl tha tir ton tur uig ukr urd uzb
+  uzb_cyrl vie yid yor);
 my %non_iso639_3 = (
     'aze-cyrl'     => 'Azerbaijani (Cyrillic)',
     'chi-sim'      => 'Simplified Chinese',
@@ -85,9 +93,9 @@ sub setup {
 sub languages {
     if ( not %languages ) {
         my @codes;
-        my ( undef, $out, $err ) =
+        my ( undef, $out ) =
           Gscan2pdf::Document::exec_command( [ 'tesseract', '--list-langs' ] );
-        @codes = split /\n/xsm, $err ? $err : $out;
+        @codes = split /\n/xsm, $out;
         if ( $codes[0] =~ /^List[ ]of[ ]available[ ]languages/xsm ) {
             shift @codes;
         }
@@ -184,23 +192,24 @@ sub hocr {
 
         # Temporary filename for new file
         $tif = File::Temp->new( SUFFIX => '.tif' );
-        my $image = Image::Magick->new;
-        $image->Read( $options{file} );
 
-        my $x;
+        my @cmd;
         if ( defined $options{threshold} and $options{threshold} ) {
             $logger->info("thresholding at $options{threshold} to $tif");
-            $image->BlackThreshold( threshold => "$options{threshold}%" );
-            $image->WhiteThreshold( threshold => "$options{threshold}%" );
-            $x = $image->Set( alpha => 'Off' );
-            $x = $image->Quantize( colors => 2 );
-            $x = $image->Write( depth => 1, filename => $tif );
+            @cmd = (
+                'convert', $options{file}, '+dither', '-threshold',
+                "$options{threshold}%", '-depth', 1, $tif,
+            );
         }
         else {
             $logger->info("writing temporary image $tif");
-            $x = $image->Write( filename => $tif );
+            @cmd = ( 'convert', $options{file}, $tif );
+        }
+        my ( $status, $stdout, $stderr ) =
+          Gscan2pdf::Document::exec_command( \@cmd );
+        if ( $status != 0 ) {
+            return $stdout, $stderr;
         }
-        if ("$x") { $logger->warn($x) }
     }
     else {
         $tif = $options{file};
